@@ -27,14 +27,3 @@ documentation.  For more information on the Python package, licence and source c
 
 
 name = 'sluyspy'
-
-from . import cli
-from . import plot
-from . import solar_panels
-from . import text
-from . import weather
-
-
-# Avoid F401 "'module' imported but unused" warnings:
-if False:
-    print(cli, plot, solar_panels, text, weather)
